==> jtimer-1.3.3-sources.jar: org/chorem/jtimer/entities/ConnectionData.java <==
/*
 * #%L
 * jTimer
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2007 - 2012 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
/* *##%
 * Copyright (C) 2008, 2009 Code Lutin
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *##%*/

package org.chorem.jtimer.entities;

import java.io.Serializable;

/**
 * Data class to get login, password... for ws.
 *
 * @author chatellier
 * @version $Revision: 2607 $
 * 
 * Last update : $Date: 2009-06-18 17:19:19 +0200 (jeu., 18 juin 2009) $
 * By : $Author: echatellier $
 */
public class ConnectionData implements Serializable {

    /** serialVersionUID. */
    private static final long serialVersionUID = 8693017788987110830L;

    /** login. */
    protected String login;

    /**
     * Get login.
     * 
     * @return the login
     */
    public String getLogin() {
        return login;
    }

    /**
     * Set login.
     * 
     * @param newLogin the login to set
     */
    public void setLogin(String newLogin) {
        this.login = newLogin;
    }
}

==> jtimer-1.4.2-sources.jar: org/chorem/jtimer/entities/ConnectionData.java <==
/*
 * #%L
 * jTimer
 * 
 * $Id: ConnectionData.java 2778 2011-09-05 08:12:54Z echatellier $
 * $HeadURL$
 * %%
 * Copyright (C) 2008 - 2011 CodeLutin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

package org.chorem.jtimer.entities;

import java.io.Serializable;

/**
 * Data class to get login, password... for ws.
 *
 * @author chatellier
 * @version $Revision: 2778 $
 * 
 * Last update : $Date: 2011-09-05 10:12:54 +0200 (Mon, 05 Sep 2011) $
 * By : $Author: echatellier $
 */
public class ConnectionData implements Serializable {

    /** serialVersionUID. */
    private static final long serialVersionUID = 8693017788987110830L;

    /** login. */
    protected String login;

    /**
     * Get login.
     * 
     * @return the login
     */
    public String getLogin() {
        return login;
    }

    /**
     * Set login.
     * 
     * @param login the login to set
     */
    public void setLogin(String login) {
        this.login = login;
    }
}
